@@ -105,7 +105,6 @@ f_venue FoursquareComm::itemToVenue(QScriptValue qv, bool extended)
     l.postalCode = qsvl.property("postalCode").toString();
     l.state = qsvl.property("state").toString();
     l.crossStreet = qsvl.property("crossStreet").toString();
-
     v.location = l;
     v.name = qv.property("name").toString();
     v.id = qv.property("id").toString();
@@ -210,7 +209,7 @@ f_checkinresult FoursquareComm::itemToCheckinresult(QScriptValue qv)
     return cr;
 }
 
-QList<f_checkinresult> FoursquareComm::checkinVenue(QString venueId, QString shout, QString broadcast, QString ll, QString llAcc, QString alt, QString altAcc)
+QList<f_checkinresult> FoursquareComm::checkinVenue(QString venueId, QString shout, QString broadcast, QString ll, QString llAcc)
 {
     QList<f_checkinresult> items;
 
@@ -222,7 +221,7 @@ QList<f_checkinresult> FoursquareComm::checkinVenue(QString venueId, QString sho
     if(llAcc!="")
         parameters.append("&llAcc="+llAcc);
     if(shout!="")
-        parameters.append("&shout="+shout);
+        parameters.append("&shout="+shout.toUtf8());
     QString a = oa->getUrl("checkins/add");
     QNetworkAccessManager * testnam = new QNetworkAccessManager(this);
     qDebug() << "url: "+a;
@@ -250,8 +249,6 @@ QList<f_checkinresult> FoursquareComm::checkinVenue(QString venueId, QString sho
             return items;
         }
 
-
-
         QScriptValueIterator it(sc.property("notifications"));
         while (it.hasNext()) {
             it.next();
@@ -370,3 +367,91 @@ QString FoursquareComm::doRequest(QString a)
     }
     return QString("");
 }
+
+f_venue FoursquareComm::addVenue(QString name, QString address, QString crossStreet, QString city, QString state, QString zip, QString phone, QString ll, QString primaryCategoryId)
+{
+    f_venue resultvenue;
+
+    qDebug() << "addVenue";
+    QByteArray parameters;
+    parameters.append("name="+name.toUtf8());
+    parameters.append("&address="+address.toUtf8());
+    parameters.append("&crossStreet="+crossStreet.toUtf8());
+    parameters.append("&city="+city.toUtf8());
+    parameters.append("&state="+state.toUtf8());
+    parameters.append("&zip="+zip.toUtf8());
+    parameters.append("&phone="+phone.toUtf8());
+    //parameters.append("&primaryCategoryId="+primaryCategoryId); //TODO implement this
+    parameters.append("&ll="+ll);
+    QString a = oa->getUrl("venues/add");
+    QNetworkAccessManager * testnam = new QNetworkAccessManager(this);
+    qDebug() << "url: "+a;
+    qDebug() << "Postdata: "+parameters;
+    QUrl url(a);
+    QNetworkReply * reply = testnam->post(QNetworkRequest(url),parameters);
+
+    // execute an event loop to process the request (nearly-synchronous)
+    QEventLoop eventLoop;
+    // also dispose the event loop after the reply has arrived
+    connect(testnam, SIGNAL(finished(QNetworkReply *)), &eventLoop, SLOT(quit()));
+    eventLoop.exec();
+
+    if (reply->error() == QNetworkReply::NoError)
+    {
+        QByteArray result = reply->readAll();  // bytes
+        qDebug() << QString(result);
+        QScriptValue sc;
+        QScriptEngine engine;
+        sc = engine.evaluate("(" + QString::fromUtf8(result) + ")");
+
+        if(sc.property("meta").property("code").toNumber()!=200)
+        {
+            qDebug() << "Error occured";
+            return resultvenue;
+        }
+
+        resultvenue = itemToVenue(sc.property("result").property("venue"));
+        return resultvenue;
+    }
+    else
+    {
+        qDebug() << "Error occured: "+reply->errorString();
+    }
+    qDebug() << "searchVenues done";
+    return resultvenue;
+}
+
+QList<f_tip> FoursquareComm::getNearbyTips(QString ll)
+{
+    QList<f_tip> tips;
+    qDebug() << "getNearbyTips";
+    QString a = oa->getUrl("tips/search","&ll="+ll);
+    QString result = doRequest(a);
+    QScriptEngine engine;
+    //sc = engine.evaluate(QString(result)); // In new versions it may need to look like engine.evaluate("(" + QString(result) + ")");
+    QScriptValue sc = engine.evaluate("(" + QString(result) + ")");
+
+    QScriptValueIterator it(sc.property("response").property("tips"));
+    while (it.hasNext()) {
+        it.next();
+        if(it.value().property("id").toString()!="")
+        {
+            tips.append(itemToTip(it.value()));
+        }
+    }
+
+    qDebug() << "getNearbyTips done";
+    return tips;
+}
+
+f_tip FoursquareComm::itemToTip(QScriptValue qv)
+{
+    f_tip t;
+    t.id = qv.property("id").toString();
+    t.text = qv.property("text").toString();
+    t.createdAt = qv.property("createdAt").toString();
+    t.url = qv.property("url").toString();
+    t.user = itemToUser(qv.property("user"));
+    t.venue = itemToVenue(qv.property("venue"));
+    return t;
+}
