@@ -91,6 +91,16 @@ struct f_checkinresult {
     QMap<QString,QString> values;
 };
 
+struct f_tip {
+    QString id;
+    QString createdAt;
+    QString text;
+    QString url;
+    //TODO: todo en done
+    f_venue venue;
+    f_user user;
+};
+
 class FoursquareComm: public QObject
 {
     Q_OBJECT
@@ -102,15 +112,18 @@ private:
     static FoursquareComm *inst;
     f_checkin itemToCheckin(QScriptValue qv);
     QString doRequest(QString a);
+    f_tip itemToTip(QScriptValue qv);
 protected:
     FoursquareComm();
 public:
     static FoursquareComm *instance();
     QList<f_checkin> getRecentCheckins();
     QList<f_venue> searchVenues(QString ll, QString llAcc = QString(""), QString query = QString(""));
-    QList<f_checkinresult> checkinVenue(QString venueId, QString shout, QString broadcast, QString ll, QString llAcc="", QString alt="", QString altAcc="");
+    QList<f_checkinresult> checkinVenue(QString venueId, QString shout, QString broadcast, QString ll, QString llAcc="");
+    f_venue addVenue(QString name, QString address, QString crossStreet, QString city, QString state, QString zip, QString phone, QString ll, QString primaryCategoryId="");
     f_venue getVenue(QString id);
     f_user getUser(QString id = "self");
+    QList<f_tip> getNearbyTips(QString ll);
 signals:
     void venueReady(f_venue);
 };
