@@ -50,3 +50,9 @@ void MainWindow::on_pbRecent_clicked()
     rcw = new RecentCheckinsWindow(this);
     rcw->show();
 }
+
+void MainWindow::on_pbTips_clicked()
+{
+    ntf = new NearbyTipsForm(this);
+    ntf->show();
+}
