@@ -8,6 +8,7 @@
 #include "searchvenueswindow.h"
 #include "leaderboard.h"
 #include "recentcheckinswindow.h"
+#include "nearbytipsform.h"
 
 QTM_USE_NAMESPACE
 
@@ -26,6 +27,7 @@ public:
     PositionSource * ps;
     LeaderBoard * lb;
     RecentCheckinsWindow * rcw;
+    NearbyTipsForm * ntf;
 
 private:
     Ui::MainWindow *ui;
@@ -33,6 +35,7 @@ private:
     SearchVenuesWindow * svw;
 
 private slots:
+    void on_pbTips_clicked();
     void on_pbRecent_clicked();
     void on_pbLeaderboard_clicked();
     void on_pbSearchVenue_clicked();
