@@ -38,7 +38,6 @@ void VenueDetails::setVenue(f_venue v)
     this->setLabelText(ui->lblCheckinCount,QString::number(v.checkinsCount));
     this->setLabelText(ui->lblCity,v.location.city);
     this->setLabelText(ui->lblCrossStreet,v.location.crossStreet);
-    this->setLabelText(ui->lblDistance,QString::number(v.location.distance));
     this->setLabelText(ui->lblHereNow,QString::number(v.hereNowCount));
     this->setLabelText(ui->lblPostalCode,v.location.postalCode);
     this->setLabelText(ui->lblState,v.location.state);
@@ -47,7 +46,7 @@ void VenueDetails::setVenue(f_venue v)
     this->setLabelText(ui->lblDescription,v.description);
     if(!v.extendedInfo)
     {
-        connect(fsc,SIGNAL(venueReady(f_venue)),this,SLOT(setVenue(f_venue)));
+        //connect(fsc,SIGNAL(venueReady(f_venue)),this,SLOT(setVenue(f_venue)));
         //extern void getVenueDetails(QString id);
         //QFuture<void> f1 = QtConcurrent::run(getVenueDetails,QString(venue.id));
         //extern f_venue getVenue(QString);
